@@ -1,6 +1,4 @@
-from .wordnet import *
 from .dto import *
-from .find_wordnet import FindWordnet
 from .find_dictionaries import FindDictionaries
 from .find_stopwords import FindStopWords
 from .find_pronouns import FindPronouns
